@@ -14,18 +14,21 @@ import warnings
 
 warnings.filterwarnings("ignore", category=FutureWarning)
 
-def simplify(s, delta=0.05):
-    
-    while not check_length(s):
+
+def _simplify(s, threshold, delta=0.005):
+
+    while not _check_length(s, threshold):
         s = s.simplify(delta, False)
-        delta = delta + 0.05
+        delta = delta + 0.005
 
     return s
 
-def check_length(s, threshold=3000):
-    
+
+def _check_length(s, threshold):
+
     return len(str(s)) < threshold
 
+
 def get_area(s):
     s = shape(s)
     proj = partial(
@@ -128,7 +131,7 @@ def overpass_request(geo):
     return [e["tags"] for e in response.json()["elements"]]
 
 
-def get(geometry, threshold_value=1000000):
+def get(geometry, threshold_value=1000000, simplify=True, simplify_limit=5000):
     """Get Open Street Maps highways length in meters and object count for a given geometry
 
     It splits the regions to manage overpass turbo limits.
@@ -141,6 +144,10 @@ def get(geometry, threshold_value=1000000):
         A shapely polygon
     threshold_value : int, optional
         Maximum area in sq km to split the polygons, by default 1000000
+    simplify: bool, optional
+        Simplify polygon to maximum number of characters
+    simplify_limit: int, optional
+        Maximum number of characters of WKT shape
 
     Returns
     -------
@@ -153,6 +160,9 @@ def get(geometry, threshold_value=1000000):
     responses = []
     for geo in geometries:
 
+        if simplify:
+            geo = _simplify(geo, simplify_limit)
+
         geo = to_overpass_coords(geo)
         responses.append(overpass_request(geo))
 
